package com.ruoyi.system.mapper.notice;

import com.ruoyi.system.domain.notice.InfoPinglun;
import com.ruoyi.system.domain.notice.XiaoyuanInfo;

import java.util.List;

/**
 * 校园安全信息Mapper接口
 * 
 * @author boman
 * @date 2023-08-01
 */
public interface XiaoyuanInfoMapper 
{
    /**
     * 查询校园安全信息
     * 
     * @param infoId 校园安全信息主键
     * @return 校园安全信息
     */
    public XiaoyuanInfo selectXiaoyuanInfoByInfoId(Long infoId);

    /**
     * 查询校园安全信息列表
     * 
     * @param xiaoyuanInfo 校园安全信息
     * @return 校园安全信息集合
     */
    public List<XiaoyuanInfo> selectXiaoyuanInfoList(XiaoyuanInfo xiaoyuanInfo);

    /**
     * 新增校园安全信息
     * 
     * @param xiaoyuanInfo 校园安全信息
     * @return 结果
     */
    public int insertXiaoyuanInfo(XiaoyuanInfo xiaoyuanInfo);

    /**
     * 修改校园安全信息
     * 
     * @param xiaoyuanInfo 校园安全信息
     * @return 结果
     */
    public int updateXiaoyuanInfo(XiaoyuanInfo xiaoyuanInfo);

    /**
     * 删除评论
     * @param infoPinglun
     * @return
     */
    public int deletePingLun(InfoPinglun infoPinglun);

    /**
     * 增加已读数量
     * @param xiaoyuanInfo
     * @return
     */
    public int updateXiaoyuanInfoYiDu(XiaoyuanInfo xiaoyuanInfo);

    /**
     * 删除校园安全信息
     * 
     * @param infoId 校园安全信息主键
     * @return 结果
     */
    public int deleteXiaoyuanInfoByInfoId(Long infoId);

    /**
     * 批量删除校园安全信息
     * 
     * @param infoIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteXiaoyuanInfoByInfoIds(Long[] infoIds);

    /**
     * 批量删除校园安全信息评论
     * 
     * @param infoIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteInfoPingLunByInfoIds(Long[] infoIds);
    
    /**
     * 批量新增校园安全信息评论
     * 
     * @param infoPinglunList 校园安全信息评论列表
     * @return 结果
     */
    public int batchInfoPingLun(List<InfoPinglun> infoPinglunList);
    

    /**
     * 通过校园安全信息主键删除校园安全信息评论信息
     * 
     * @param infoId 校园安全信息ID
     * @return 结果
     */
    public int deleteInfoPingLunByInfoId(Long infoId);
}
